summaryrefslogtreecommitdiffstats
path: root/chrome/renderer/chrome_render_process_observer.h
diff options
context:
space:
mode:
authormarja@chromium.org <marja@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-11-08 12:08:12 +0000
committermarja@chromium.org <marja@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-11-08 12:08:12 +0000
commitf6779a644fd46a4574869610b8a7ac5a38dfc7c2 (patch)
treeb2fefbe652d96df0209f2da3b9481b8cda0c10cc /chrome/renderer/chrome_render_process_observer.h
parent4b4737482b4af117d20cdfc1f8c7fdd005921ea2 (diff)
downloadchromium_src-f6779a644fd46a4574869610b8a7ac5a38dfc7c2.zip
chromium_src-f6779a644fd46a4574869610b8a7ac5a38dfc7c2.tar.gz
chromium_src-f6779a644fd46a4574869610b8a7ac5a38dfc7c2.tar.bz2
Revert 109005 - Take script URLs into account when applying script content settings.
Transmit script content settings to the renderer. Use the script URL as the secondary URL for the content setting rules. BUG=90840 TEST=ChromeRenderViewTest.ContentSettings(Allow|Block)Scripts Review URL: http://codereview.chromium.org/8409006 TBR=marja@chromium.org Review URL: http://codereview.chromium.org/8502014 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@109014 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/renderer/chrome_render_process_observer.h')
-rw-r--r--chrome/renderer/chrome_render_process_observer.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/chrome/renderer/chrome_render_process_observer.h b/chrome/renderer/chrome_render_process_observer.h
index 74ab740..e3ba711 100644
--- a/chrome/renderer/chrome_render_process_observer.h
+++ b/chrome/renderer/chrome_render_process_observer.h
@@ -45,9 +45,9 @@ class ChromeRenderProcessObserver : public content::RenderProcessObserver {
// |ChromeRenderProcessObserver|.
const ContentSettings* default_content_settings() const;
// Returns a pointer to the content setting rules owned by
// |ChromeRenderProcessObserver|.
- const RendererContentSettingRules* content_setting_rules() const;
+ const ContentSettingsForOneType* image_setting_rules() const;
private:
// RenderProcessObserver implementation.
@@ -58,7 +58,7 @@ class ChromeRenderProcessObserver : public content::RenderProcessObserver {
void OnSetContentSettingsForCurrentURL(
const GURL& url, const ContentSettings& content_settings);
void OnSetDefaultContentSettings(const ContentSettings& content_settings);
- void OnSetContentSettingRules(const RendererContentSettingRules& rules);
+ void OnSetImageSettingRules(const ContentSettingsForOneType& settings);
void OnSetCacheCapacities(size_t min_dead_capacity,
size_t max_dead_capacity,
size_t capacity);
@@ -80,7 +80,7 @@ class ChromeRenderProcessObserver : public content::RenderProcessObserver {
// If true, the web cache shall be cleared before the next navigation event.
bool clear_cache_pending_;
ContentSettings default_content_settings_;
- RendererContentSettingRules content_setting_rules_;
+ ContentSettingsForOneType image_setting_rules_;
DISALLOW_COPY_AND_ASSIGN(ChromeRenderProcessObserver);
};
@@ -45,9 +45,9 @@ class ChromeRenderProcessObserver : public content::RenderProcessObserver {
// |ChromeRenderProcessObserver|.
const ContentSettings* default_content_settings() const;
- // Returns a pointer to the content setting rules owned by
+ // Returns a pointer to the image setting rules owned by
// |ChromeRenderProcessObserver|.